package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!`````ID$"#0```!HL@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(T*T`
M`-"M```%`````!````$```#XK@``^#X%"/@^!0@P`@``G!(```8`````$```
M`@````2O```$/P4(!#\%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&00GP``$!\%"!`?!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D^*X`
M`/@^!0CX/@4("`$```@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`03V,D/"![,);G]Y?8V-+3`HB-7DE````1`````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$#`A$````1@``````````````````
M`$@```!*````2P````````!,````30```$\```!0````40```%(`````````
M5```````````````50```%8```!9``````````````!:````7````%T```!?
M`````````&$```!C``````````````!E````9@```&<`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSR
MV],=^J%L8+F-\0X`````````````````````X`(`````````````$@```(8#
M`````````````!(````D`@`````````````2````$0``````````````(```
M`/0#`````````````!(```!W`P`````````````2````/0$`````````````
M$@```/L"`````````````!(```#3```````````````2````YP(`````````
M````$@```*\``````````````!(````X`0`````````````2````G@(`````
M````````$@```#0#`````````````!(```"O`@`````````````2````H0$`
M````````````$@```$0#`````````````!(````[`P`````````````2````
M80$`````````````$@```.$``````````````!(```#K`0`````````````2
M````B`$`````````````$@```&T"`````````````!(````<`@``````````
M```2````RP(`````````````$@```-@!`````````````!(```"\`@``````
M```````2````Y`$`````````````$@```&\!`````````````!(```!+`P``
M```````````2````+0``````````````(````'\"`````````````!(```!8
M`P`````````````2````>```````````````$@```-D"`````````````!(`
M``"-`P`````````````2````%0(`````````````$@````\!````````````
M`!(```"^```````````````2````E@$`````````````$@```+8"````````
M`````!(```",`@`````````````2````/0(`````````````$@```,0"````
M`````````!(```!J```````````````2````0@$`````````````$@````(#
M`````````````!(```#-`0`````````````2````'`$`````````````$@``
M`'\#`````````````!(```#2`@`````````````2````KP$`````````````
M$@```#P``````````````"````#S```````````````2````?P$`````````
M````$@```%\#`````````````!(```#M`@`````````````2````AP``````
M````````$@```%```````````````"````"$`@`````````````2````(P,`
M````````````$@```"D"`````````````!(````0`P`````````````2````
M3@(`````````````$@```)4"`````````````!(````;`P`````````````2
M````:0,`````````````$@```$X!``!0E00(`````!(```!L!```R-\$"`0`
M```1``\`(@0``&#.!`@W#```$@`-`',$``#0R@0(MP$``!(`#0#+`P``M-\$
M"``````2``X`H0,``$!!!0@$````(0`9`-$#``#@QP0(!0```!(`#0!2!```
M4-\$"%T````2``T`G@````"6!`@`````$@```"T!``!0004(!````!$`&0`O
M!```&$$%"``````0`!@`+0,``$A!!0@$````$0`9`#$$```8004(`````"``
M&`"@`P``0$$%"`0````A`!D`P0,``+#?!`@"````$@`-`&($```D004(!```
M`!$`&`"(!```\,<$"+P!```2``T``@$``%1!!0@!````$0`9`)\#``!`004(
M!````!$`&0":`P``X)8$""("```2``T`IP0``)#,!`AI````$@`-`.(#````
MS00()````!(`#0#]`P``<-X$"&D````2``T`L`,``"A!!0@`````$``9`+P#
M``"4404(`````!``&0!>`@``S-\$"`0````1``\`T00``*#:!`C.`P``$@`-
M`#P$```@QP0(L0```!(`#0`U!````ID$"``````2``T`O0$``#"3!`@`````
M$@```!8$``#@R00(Z````!(`#0"I`P``*$$%"``````0`!@`"00``+#)!`@B
M````$@`-`+4$``#@W@0(.````!(`#0"`!```H,8$""<````2``T`]@$``%A!
M!0@3````$0`9`)4$```PS00()@$``!(`#0""!```=)($"``````2``L``&QI
M8G!E<FPN<V\N-2XR,`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R
M;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E
M96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO
M;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A
M=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?
M8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S
M=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T
M<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B
M87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R
M7W!L`%]F<%]H=P!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T-,14%24U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N
M,@!'3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT
M``````(``@`#`````@`"``(``@````(```````0``@`"`````@`"````````
M````!0`&``(````"``(````'`````@`"`````@`"``8``````````@`"``,`
M`@``````!P```````@`"````````````"``'```````"``@``P`(``,``@`"
M``<````!``$``0`!``(``0`!```````!``(``0`"``$``0`!`````@`!``$`
M`0`!``$``0`!``$``0`!`````0`!``$``0`!`````0`!`````0`"``4"```0
M````,````!)I:0T```8`YP0``!`````0:6D-```#`/$$`````````0`%`%0"
M```0`````````!)I:0T```@`YP0``!````!T&6D)```'`/L$```0````<AEI
M"0``!0`'!0``$````!1I:0T```0`$P4``!`````0:6D-```"`/$$````````
M_#\%"`8?``!`004(!58``$A!!0@%3P``4$$%"`5-``!4004(!54``%A!!0@%
M9P``#$`%"`<!```00`4(!P(``!1`!0@'`P``&$`%"`<%```<0`4(!P8``"!`
M!0@'!P``)$`%"`<(```H0`4(!PD``"Q`!0@'80``,$`%"`<*```T0`4(!PL`
M`#A`!0@'#```/$`%"`<-``!`0`4(!PX``$1`!0@'#P``2$`%"`<0``!,0`4(
M!Q$``%!`!0@'$@``5$`%"`<3``!80`4(!Q0``%Q`!0@'%0``8$`%"`<6``!D
M0`4(!Q<``&A`!0@'&```;$`%"`<9``!P0`4(!QH``'1`!0@'&P``>$`%"`<<
M``!\0`4(!QT``(!`!0@''@``A$`%"`<?``"(0`4(!R```(Q`!0@'(0``D$`%
M"`<B``"40`4(!R,``)A`!0@')```G$`%"`<E``"@0`4(!R8``*1`!0@')P``
MJ$`%"`<H``"L0`4(!RD``+!`!0@'*@``M$`%"`=$``"X0`4(!RL``+Q`!0@'
M+```P$`%"`<M``#$0`4(!RX``,A`!0@'+P``S$`%"`<P``#00`4(!S$``-1`
M!0@',@``V$`%"`<S``#<0`4(!S0``.!`!0@'3```Y$`%"`<V``#H0`4(!S<`
M`.Q`!0@'.```\$`%"`<Y``#T0`4(!SH``/A`!0@'/```_$`%"`<]````004(
M!SX```1!!0@'/P``"$$%"`=````,004(!T$``!!!!0@'0@``%$$%"`=#``!3
M@^P(Z+,&``"!PX.M``"+@_S___^%P'0%Z/X!``"#Q`A;PP```````````/\U
M!$`%"/\E"$`%"`````#_)0Q`!0AH`````.G@_____R400`4(:`@```#IT/__
M__\E%$`%"&@0````Z<#_____)1A`!0AH&````.FP_____R4<0`4(:"````#I
MH/____\E($`%"&@H````Z9#_____)21`!0AH,````.F`_____R4H0`4(:#@`
M``#I</____\E+$`%"&A`````Z6#_____)3!`!0AH2````.E0_____R4T0`4(
M:%````#I0/____\E.$`%"&A8````Z3#_____)3Q`!0AH8````.D@_____R5`
M0`4(:&@```#I$/____\E1$`%"&AP````Z0#_____)4A`!0AH>````.GP_O__
M_R5,0`4(:(````#IX/[___\E4$`%"&B(````Z=#^____)51`!0AHD````.G`
M_O___R580`4(:)@```#IL/[___\E7$`%"&B@````Z:#^____)6!`!0AHJ```
M`.F0_O___R5D0`4(:+````#I@/[___\E:$`%"&BX````Z7#^____)6Q`!0AH
MP````.E@_O___R5P0`4(:,@```#I4/[___\E=$`%"&C0````Z4#^____)7A`
M!0AHV````.DP_O___R5\0`4(:.````#I(/[___\E@$`%"&CH````Z1#^____
M)81`!0AH\````.D`_O___R6(0`4(:/@```#I\/W___\EC$`%"&@``0``Z>#]
M____)9!`!0AH"`$``.G0_?___R640`4(:!`!``#IP/W___\EF$`%"&@8`0``
MZ;#]____)9Q`!0AH(`$``.F@_?___R6@0`4(:"@!``#ID/W___\EI$`%"&@P
M`0``Z8#]____):A`!0AH.`$``.EP_?___R6L0`4(:$`!``#I8/W___\EL$`%
M"&A(`0``Z5#]____);1`!0AH4`$``.E`_?___R6X0`4(:%@!``#I,/W___\E
MO$`%"&A@`0``Z2#]____)<!`!0AH:`$``.D0_?___R7$0`4(:'`!``#I`/W_
M__\ER$`%"&AX`0``Z?#\____)<Q`!0AH@`$``.G@_/___R700`4(:(@!``#I
MT/S___\EU$`%"&B0`0``Z<#\____)=A`!0AHF`$``.FP_/___R7<0`4(:*`!
M``#IH/S___\EX$`%"&BH`0``Z9#\____)>1`!0AHL`$``.F`_/___R7H0`4(
M:+@!``#I</S___\E[$`%"&C``0``Z6#\____)?!`!0AHR`$``.E0_/___R7T
M0`4(:-`!``#I0/S___\E^$`%"&C8`0``Z3#\____)?Q`!0AHX`$``.D@_/__
M_R4`004(:.@!``#I$/S___\E!$$%"&CP`0``Z0#\____)0A!!0AH^`$``.GP
M^____R4,004(:``"``#IX/O___\E$$$%"&@(`@``Z=#[____)11!!0AH$`(`
M`.G`^___C4PD!(/D\/]Q_%6)Y59348G+@^Q`BT$$B474BT$(B4709:$4````
MB47D,<"-1=!0C4744%'HIOW__X/$#&A0E00(:%"5!`AH`)8$".CO1P``@\00
M@#U4004(`'4QZ*[\__^%P*.0404(#X2I`0``@^P,4.CX^___6?\U4$$%".@<
M____@\00QH`=!0```(/L#/\U4$$%".@$____@(C.`@```EK_-5!!!0CH\?[_
M_X"(S@(```&+`X/$$,=%Q`````"#P`6)1<#?;<#8!00?!0C=!0@?!0C9R=_I
MW=@/AP,!``"#[`S!X`)0Z''\__^+==2+&X/$$*.$404(QP6(404(!````(L6
M@_L!QT`$J^$$",=`#*[A!`B)$(L5)$$%"(E0"+H!````?A.0C70F`(L,EHE,
MD`R#P@$YVG7R@^P,QT28#`````"#PP-J`%!3:-#&!`C_-9!1!0CH</W__X/$
M((7`B<-T48/L#/\UD%$%".A)^___C57@N&_@!`CHW"8``(/$$(7`=$2#[`S_
M-9!1!0CHY_K__^@"_?__@\00B=B+=>1E,S44````=62-9?196UY=C6'\PX/L
M#/\UD%$%".AX_?__@\00B</KFJ&,404(A<!T'X/L#%#HKT4``(/$$.NE4%!H
M6$$%"&@?X`0(Z#G\__^-5>"X).`$".A<)@``A<"CC%$%"`^$>O___^O%Z'CZ
M__^#[`QJ`>B>^___,>U>B>&#Y/!05%)HL-\$"&A0WP0(459HX)8$".B]^___
M]&:09I!FD&:09I!FD(L<),-FD&:09I!FD&:09I"X*T$%""TH004(@_@&=AJX
M`````(7`=!%5B>6#[!1H*$$%"/_0@\00R?/#D(UT)@"X*$$%""TH004(P?@"
MB<+!ZA\!T-'X=!NZ`````(72=!)5B>6#[!!0:"A!!0C_TH/$$,GSPXUT)@"-
MO"<`````@#UK004(`'4358GE@^P(Z'S____&!6M!!0@!R?/#9I"X`#\%"(L0
MA=)U!>N3C78`N@````"%TG3R58GE@^P44/_2@\00R>EU____9I!FD)!55S'M
M5E.![`P#``")1"1H@\`XB70D"&6+%10```")E"3\`@``,=*)!"2)?"0,9I"+
M!"3'1.Q\`````,>$[(0`````````BU2H!(L$J(G!B<:)U\'A",'F&('A``#_
M``GQB<8/K-8(@>8`_P``"<Z)P8G0#ZS1&#'2@>'_````"?&)_HE,['B)^<'F
M&,'A"('A``#_``G.B?D/K-$(#ZS0&('A`/\```GQ)?\````)R(F$[(````"#
MQ0*#_1`/A6W___^-A"3@````C90DX`(``(VT)@````"+6-B+2-R#P`@S6/@S
M2/PS6*`S2*0S6)`S2)3'0!0`````B<^)V8G>#ZSY'XG[B0PDB?'!ZQ\!\0L,
M)(E<)`2)2!`YT'6ZBT0D:(M(#(M8$(M0"(MP%(LXBV@$B4PD!(M(&(E<)`B+
M6!R)%"2)="0,B4PD,(M(((E<)#2+6"2)^(E$)"B);"0LB4PD4`-,)'B)7"14
M$UPD?(G:B<N!PYEY@EJ)UH/6`(G9P>`%B?.)_HG/#ZSN&S'2B=T)QHL$)`'W
MB7PD$(M\)`@1U8G&B6PD%/?6B?.+="0P(?.)_HM\)!`AQHET)!B+;"08"=T!
M[XE\)"")?"00BP0DBU0D!(M,)"C'1"04`````,=$)!P`````QT0D/`````")
MQXG&QT0D1``````/K-<"P>8>BU0D%,=$)"0`````B?V+?"0P"?4#O"2`````
MB<Z);"0X]]:+;"0XB?B+?"0H!9EY@EHC="0((<T)]8GIBVPD+`'!BT0D$(G+
MB?F)QL'@!0^LUAN+5"00"<8!\\'G'@^LZ0+WTHE<)!B)7"18B<V+3"0("?T#
MC"2(````B6PD0(ML)""!P9EY@EHC5"0X(VPD0(GHB=6+5"0<"<6+1"08`>F)
MRXG&P>`%#ZS6&PG&`?.+="00B5PD8(E<)""+?"04BU0D.(GQP>8>QT0D%```
M``#'1"1,`````,=$)#P`````#ZSY`HM\)!S'1"0<`````(G-"?4#E"20````
MB6PD2(ML)%B)T8M4)!B!P9EY@EHC;"1(]](C5"1`B>B)U8M4)"0)Q8M$)"`!
MZ8G+B<;!X`4/K-8;BU0D0`G&`?.+="08B5PD$(E<)%B)\<'F'@^L^0*+?"0D
MB<T)]0.4))@```");"0XBVPD8(G1BU0D(('!F7F"6B-L)#CWTB-4)$B)Z(G5
MBU0D%`G%BT0D$`'IB<N)QL'@!0^LUAL)Q@'SBW0D((E<)&")7"08B?'!YAX/
MK/D"B<T)]8EL)$"+5"1(`Y0DH````(ML)%B+?"04QT0D)`````#'1"1$````
M`,=$)$P`````QT0D%`````#'1"0\`````(G1BU0D$('!F7F"6B-L)$#WTB-4
M)#B)Z(G5BU0D'`G%BT0D&`'IB<N)QL'@!0^LUAN+5"0X"<8!\XMT)!")7"0@
MB5PD6(GQP>8>#ZSY`HM\)!R)S0GU`Y0DJ````(EL)$B+;"1@B=&+5"08@<&9
M>8):(VPD2/?2(U0D0(GHB=6+5"0D"<6+1"0@`>F)RXG&P>`%#ZS6&PG&`?.+
M="08B5PD8(E<)!")\<'F'@^L^0*)S0GUB6PD.(M4)$`#E"2P````BVPD6(M\
M)"3'1"0<`````,=$)$0`````QT0D)`````#'1"1,`````(G1BU0D(('!F7F"
M6B-L)#CWTB-4)$B)Z(G5BU0D%`G%BT0D$`'IB<N)QL'@!0^LUAN+5"1("<8!
M\XMT)"")7"08B5PD6(GQP>8>#ZSY`HM\)!2)S0GU`Y0DN````(EL)$"+;"1@
MB=&+5"00@<&9>8):(VPD0/?2(U0D.(GHB=6+5"0<"<6+1"08`>F)RXG&P>`%
M#ZS6&XM4)#@)Q@'SBW0D$(E<)&")7"0@B?'!YAX/K/D"B<T)]8EL)$@#E"3`
M````BVPD6(M\)!S'1"04`````,=$)#P`````QT0D'`````#'1"1$`````(G1
MBU0D&('!F7F"6B-L)$CWTB-4)$")Z(G5BU0D)`G%BT0D(`'IB<N)QL'@!0^L
MUAN+5"1`"<8!\XMT)!B)7"00B5PD6(GQP>8>#ZSY`HM\)"2)S0GU`Y0DR```
M`(EL)#B+;"1@B=&+5"0@@<&9>8):(VPD./?2(U0D2(GHB=6+5"04"<6+1"00
M`>F)RXG&P>`%#ZS6&XM4)$@)Q@'SBW0D((E<)&")7"08B?'!YAX/K/D"B<T)
M]8EL)$`#E"30````BVPD6(M\)!3'1"0D`````,=$)$P`````QT0D%`````#'
M1"0\`````(G1BU0D$('!F7F"6B-L)$#WTB-4)#B)Z(G5BU0D'`G%BT0D&`'I
MB<N)QL'@!0^LUAN+5"0X"<8!\XMT)!")7"0@B5PD6(GQP>8>#ZSY`HM\)!R)
MS0GU`Y0DV````(EL)$B+;"1@B=&+5"08@<&9>8):(VPD2/?2(U0D0(GHB=6+
M5"0D"<6+1"0@`>F)RXG&P>`%#ZS6&XM4)$`)Q@'SBW0D&(E<)&")7"00B?'!
MYAX/K/D"B<T)]0.4).````");"0XB=&+5"0@BVPD6('!F7F"6B-L)#B+?"0D
MQT0D'`````#'1"1$`````/?2(U0D2,=$)"0`````QT0D3`````")Z(G5BU0D
M%`G%BT0D$`'IB<N)QL'@!0^LUAN+5"1("<8!\XMT)"")7"08B5PD6(GQP>8>
M#ZSY`HM\)!2)S0GU`Y0DZ````(EL)$"+;"1@B=&+5"00@<&9>8):(VPD0/?2
M(U0D.(GHB=6+5"0<"<6+1"08`>F)RXG&P>`%#ZS6&XM4)#@)Q@'SBW0D$(E<
M)&")7"0@B?'!YAX/K/D"B<T)]0.4)/````");"1(B=&+5"08@<&9>8):]](C
M5"1`BVPD6"-L)$B+?"0<QT0D%`````#'1"0\`````,=$)!P`````QT0D1```
M``")Z(G5BU0D)`G%BT0D(`'IB<N)QL'@!0^LUAN+5"1`"<8!\XMT)!B)7"00
MB5PD6(GQP>8>#ZSY`HM\)"2)S0GU`Y0D^````(EL)#B+;"1@B=&+5"0@@<&9
M>8):(VPD./?2(U0D2(GHB=6+5"04"<6+1"00`>F)RXG&P>`%#ZS6&XM4)$@)
MQ@'SBW0D((E<)&")7"08B?'!YAX/K/D"B<T)]0.4)``!``");"1`B=&+5"00
M@<&9>8):]](C5"0XBVPD6"-L)$"+?"04QT0D)`````#'1"1,`````(GHB=6+
M5"0<"<6+1"08`>F)RXG&P>`%#ZS6&XM4)#@)Q@'SBW0D$(E<)"")7"18B?'!
MYAX/K/D"B<V+3"0\QT0D/``````)]0.4)`@!```3C"0,`0``B6PD2(ML)&")
MRXG1BU0D&('!F7F"6H/3`"-L)$@Q__?2(U0D0(GHB=6+5"0D"<6+1"0@`>D1
M^XM\)!S'1"0<`````(G&P>`%#ZS6&S'2"<:)\(G>B<L!PQ'6B5PD8(E<)#B)
M="1DBW0D&(M4)$")\<'F'@^L^0*)S0GUB6PD;(EL)!@#E"00`0``BW0D6(M$
M)#B+?"0DQT0D%`````")T8M4)""!P9EY@EHA[HML)&SWTB-4)$@)\HG&`=&+
M5"0\P>`%B<L/K-8;BU0D2`G&`?.+="0@B5PD$(E<)$")\<'F'@^L^0*)\(G.
M"<8#E"08`0``B70D((G0BU0D%`6AZ]EN,?6)[HML)&`Q]8GI`<&+1"00B<N)
MQL'@!8E$)$B+1"0XBVPD2`^LUAN+5"0\B<$)]0'KP>`>,?\/K-$"B=Z)7"1(
MBU0D&(G+BVPD0`G#`Y0D(`$``(E<)#B)T`6AZ]EN,UPD(#'=B>D!P8GP#ZSX
M&XE$)!B)\(ML)!C!X`6)1"1`"VPD0(M4)!"+1"0@QT0D'``````!Z8E,)!B)
M3"1`BTPD%`^LR@*+3"00B=6+E"0H`0``P>$>"<V+C"0L`0``@<*AZ]ENB6PD
M((/1`(G+B=$QT@'($=HS;"0XB40D$(E4)!2+5"1(BT0D&,=$)!0`````,>J)
MT8M4)!P#3"00#ZS0&XGRB40D$(M$)!B+;"00P>`%B40D2`ML)$B+1"0X`>G!
MYAX/K/H"B4PD$(E,)$B)U0GUB[0D,`$``(EL)#B!QJ'KV6X!\(MT)"`Q[HML
M)$`Q]8GI`<&+1"00BU0D%(G+B<;!X`6)1"1`BT0D&(ML)$`/K-8;BU0D'(G!
MQT0D'``````)]0'KP>`>,?\/K-$"B=Z)7"1`BY0D.`$``(G+"<.+1"0@B=V)
M7"0@BUPD.('"H>O9;@'0BU0D%#'KBVPD2#'=B>D!P8GP#ZSX&XE$)!B)\(ML
M)!C!X`6)1"1("VPD2(M$)!`!Z8E,)!B)3"1(B<$/K-$"BY0D0`$``,'@'HG-
MBXPD1`$```G%BT0D.('"H>O9;HEL)#B#T0")RXG1,=(!R!':,VPD((E$)!")
M5"04BU0D0(M$)!@QZHG1BU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML)!#'1"04
M`````,'@!8E$)$`+;"1`BT0D(`'IP>8>#ZSZ`HE,)$")3"00B=6+5"04"?6+
MM"1(`0``B6PD(('&H>O9;@'PBW0D.#'NBVPD2#'UB>D!P8M$)!")RXG&P>`%
MB40D2(M$)!B+;"1(#ZS6&XM4)!R)P<=$)!P`````"?4!Z\'@'C'_#ZS1`HG>
MB5PD2(N4)%`!``")RPG#BT0D.(G=B5PD.(M<)""!PJ'KV6X!T(M4)!0QZXML
M)$`QW8GI`<&)\`^L^!N)1"08B?"+;"08P>`%B40D0`ML)$"+1"00`>F)3"1`
MB4PD&(G!#ZS1`HN4)%@!``#!X!Z)S8N,)%P!```)Q8M$)""!PJ'KV6Z);"0@
M@]$`B<N)T3'2`<@1VC-L)#B)1"00B50D%(M4)$B+1"08QT0D%``````QZHG1
MBU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML)!#!X`6)1"1("VPD2(M$)#@!Z<'F
M'@^L^@*)3"00B4PD2(G5BU0D%`GUB[0D8`$``(EL)#B!QJ'KV6X!\(MT)"`Q
M[HML)$`Q]8GI`<&+1"00B<N)QL'@!8E$)$"+1"08BVPD0`^LUAN+5"0<B<$)
M]0'KP>`>,?\/K-$"B=Z)7"1`BY0D:`$``(G+"<.+1"0@QT0D'`````")W8E<
M)""+7"0X@<*AZ]EN`="+5"04,>N+;"1(,=V)Z0'!B?`/K/@;B40D&(GPBVPD
M&,'@!8E$)$@+;"1(BT0D$`'IB4PD&(E,)$B)P0^LT0*+E"1P`0``P>`>B<V+
MC"1T`0``"<6+1"0X@<*AZ]ENB6PD.(/1`(G+B=$QT@'($=HS;"0@B40D$(E4
M)!2+5"1`BT0D&,=$)!0`````,>J)T8M4)!P#3"00#ZS0&XGRB40D$(M$)!B+
M;"00P>`%B40D0`ML)$`!Z<'F'@^L^@*)3"1`B4PD$(G5"?6+M"1X`0``BT0D
M((EL)""+5"04@<:AZ]EN`?"+="0X,>Z+;"1(,?6)Z0'!BT0D$(G+B<;!X`6)
M1"1(BT0D&(ML)$@/K-8;BU0D'(G!QT0D'``````)]0'KP>`>,?\/K-$"B=Z)
M7"1(BY0D@`$``(G+"<.+1"0XB=V)7"0XBUPD(('"H>O9;@'0BU0D%#'KBVPD
M0#'=B>D!P8GP#ZSX&XE$)!B)\(ML)!C!X`6)1"1`"VPD0(M$)!`!Z8E,)$")
M3"08B<$/K-$"BY0DB`$``,'@'HG-BXPDC`$```G%BT0D(('"H>O9;HEL)""#
MT0")RXG1,=(!R!':,VPD.(E$)!")5"04BU0D2(M$)!C'1"04`````#'JB=&+
M5"0<`TPD$`^LT!N)\HE$)!"+1"08BVPD$,'@!8E$)$@+;"1(BT0D.`'IP>8>
M#ZSZ`HE,)$B)3"00B=6+5"04"?6+M"20`0``B6PD.('&H>O9;@'PBW0D(#'N
MBVPD0#'UB>D!P8M$)!")RXG&P>`%B40D0(M$)!B+;"1`#ZS6&XM4)!R)P0GU
M`>O!X!XQ_P^LT0*)WHE<)$"+E"28`0``B<L)PXM$)"")W8E<)""+7"0X@<*A
MZ]EN`=`QZXML)$@QW8GI`<&)\`^L^!N)1"08B?"+;"08P>`%B40D2`ML)$B+
M1"00BU0D%,=$)!P``````>F)3"08B4PD2(G!#ZS1`HN4)*`!``#!X!Z)S8N,
M)*0!```)Q8M$)#B!PJ'KV6Z);"0X@]$`B<N)T3'2`<@1VC-L)"")1"00B50D
M%(M4)$"+1"08QT0D%``````QZHG1BU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML
M)!#!X`6)1"1`"VPD0(M$)"`!Z<'F'@^L^@*+?"1(B4PD$(G5B4PD6(M4)!0)
M]8NT)*@!``");"1`@<:AZ]EN`?"+="0X,>XQ]XGY`<&+1"00B<N)QL'@!0^L
MUAL)Q@'S,?^)7"1(BT0D&(G>BU0D'(G!P>`>#ZS1`HN4)+`!``")RXN,)+0!
M```)PXM$)#B!PJ'KV6Z)W8/1`(EL)"")RXG1,=(!R!':BUPD0(E$)!B)5"0<
MBU0D6(GPQT0D'``````QZS':B=$#3"08BU0D%`^L^!N)1"08B?"+;"08P>`%
MB40D.`ML)#B+1"00`>F)3"08B4PD6(G!#ZS1`HN4)+@!``#!X!Z)S0G%BT0D
M0('"W+P;CXEL)#B)T8M4)"`!P8G0(U0D.`GH(T0D2(E4)!"+5"0<B<4+;"00
MBT0D&`'I#ZS0&XGRB40D$(M$)!C!X`6)1"1`BVPD$`ML)$"+1"0@QT0D%```
M``#'1"0D``````'IP>8>#ZSZ`HE,)$B)3"00B=,)\XG?BYPDP`$``(G^B?J)
M?"1`BWPD',=$)!P`````@</<O!N/B=D!P8M$)#@)QB-T)%@APHM$)!")]8G&
M"=6+5"04`>G!X`6)1"0@BVPD((G+#ZS6&XN4),@!```)]8MT)!@!ZXE<)"")
M7"18B?'!YAX/K/D"B?"+?"1`B<Z+3"1("<:+1"0X@<+<O!N/B?.)]8ET)#@!
MT`G[(?TAV8GKB<*)S8M$)""+?"04"=T!ZHG1BU0D)(G&P>`%B<L/K-8;BY0D
MT`$```G&BT0D0`'SBW0D$(E<)$B)7"08BUPD.,=$)!0`````B?'!YAX/K/D"
MBWPD),=$)"0`````B<V+3"18"?6!PMR\&X^)W@'0">XAZR'QB<*+1"08"=F)
M;"1``<J)T8M4)!R)QL'@!8G+B40D$(ML)!`/K-8;BY0DV`$``(M$)#@)]8MT
M)"`!ZXML)$")7"18B5PD$(GQP>8>#ZSY`HG/BTPD2`GW@<+<O!N/B?X!T(G[
M">XAZXG"(?&+1"00B7PD.(G-BWPD'`G=`>J)QL'@!8G1BU0D%(E$)""+;"0@
MB<L/K-8;BY0DX`$```GUBW0D&`'KB5PD((E<)$B)\<'F'@^L^0*)\(M\)#B)
MSHM,)%@)QHM$)$"!PMR\&X^)\XET)$`!T`G[(=F)\XG"(?N)S8M$)"`)W0'J
MB=&+5"0DB<;!X`6)RP^LUAL)Q@'SB5PD6(MT)!"+?"04B5PD&(N4).@!``"+
M7"1`B?&+1"0XP>8>#ZSY`L=$)!P`````BWPD)(G-BTPD2,=$)!0`````"?6!
MPMR\&X^)W@'0">XAZR'QB<*+1"08"=F);"0XQT0D)``````!RHG1BU0D'(G&
MP>`%B<N)1"00BVPD$`^LUAN+E"3P`0``BT0D0`GUBW0D(`'KBVPD.(E<)!")
M7"1(B?'!YAX/K/D"B<^+3"18"?>!PMR\&X^)_@'0B?L)[B'KB<(A\8M$)!")
M?"1`B<V+?"0<"=T!ZHG&P>`%B=&+5"04B40D((ML)"")RP^LUAN+E"3X`0``
M"?6+="08`>N)7"18B5PD((GQP>8>#ZSY`HGPB<X)QHM$)#B+?"1`BTPD2('"
MW+P;CXGSB70D.,=$)!P``````=`)^R'9B?.)PB'[B<V+1"0@"=V+?"04QT0D
M%``````!ZHG1BU0D)(G&P>`%B<L/K-8;BY0D``(```G&BT0D0`'SBW0D$(E<
M)$B)7"08BUPD.(GQP>8>#ZSY`HM\)"2)S8M,)%@)]8'"W+P;CXG>`=`)[B'K
M(?&)PHM$)!@)V8EL)$`!RHG1BU0D'(G&P>`%B<N)1"00BVPD$`^LUAN+E"0(
M`@``BT0D.`GUBW0D(`'KBVPD0(E<)!")7"18B?'!YAX/K/D"B<^+3"1("?>!
MPMR\&X^)_@'0B?L)[B'KB<(A\8M$)!")?"0XB<T)W0'JB<;!X`6)T8M4)!2)
M1"0@BVPD((M\)!R)R\=$)"0`````QT0D'``````/K-8;BY0D$`(```GUBW0D
M&`'KB5PD2(E<)"")\<'F'@^L^0*)\(M\)#B)SHM,)%@)QHM$)$"!PMR\&X^)
M\XET)$`!T`G[(=F)\XG"(?N)S8M$)"`)W8M\)!3'1"04``````'JB=&+5"0D
MB<;!X`6)RP^LUAN+E"08`@``"<:+1"0X`?.+="00B5PD&(E<)%B+7"1`B?'!
MYAX/K/D"BWPD)(G-BTPD2`GU@<+<O!N/B=X!T`GN(>LA\8G"BT0D&`G9B6PD
M.`'*B=&+5"0<B<;!X`6)RXE$)!"+;"00#ZS6&XN4)"`"```)]8MT)"`!ZXE<
M)$B)7"00B?&+1"1`P>8>#ZSY`HML)#C'1"0D`````(G/BTPD6`GW@<+<O!N/
MB?X!T(G[">XAZXG"(?&+1"00B7PD0(G-BWPD',=$)!P`````"=T!ZHG&P>`%
MB=&+5"04B40D((ML)"")RP^LUAN+E"0H`@``"?6+="08`>N)7"18B5PD((GQ
MP>8>#ZSY`HGPBWPD0(G.BTPD2`G&BT0D.('"W+P;CXGSB70D.`'0"?LAV8GS
MB<(A^XG-BT0D(`G=BWPD%`'JB=&+5"0DB<;!X`6)RP^LUAN+E"0P`@``"<:+
M1"1``?.+="00B5PD&(E<)$B+7"0XB?'!YAX/K/D"B<V+3"18"?6!PMR\&X^)
MW@'0">XAZR'QB<*+1"08"=F);"1``<J)T8M4)!R)QL'@!8G+B40D$(ML)!`/
MK-8;BWPD)(N4)#@"```)]8MT)""+1"0X`>N+;"1`QT0D%`````")7"18B5PD
M$(GQP>8>QT0D)``````/K/D"B<^+3"1("?>!PMR\&X^)_@'0B?L)[B'KB<(A
M\8M$)!")?"0XB<V+?"0<QT0D'``````)W0'JB<;!X`6)T8M4)!2)1"0@BVPD
M((G+#ZS6&XN4)$`"```)]8MT)!@!ZXE<)"")7"1(B?'!YAX/K/D"B?"+?"0X
MB<Z+3"18"<:+1"1`@<+<O!N/B?.)="1``=`)^R'9B?.)PB'[B<V+1"0@"=V+
M?"04`>J)T8M4)"2)QL'@!8G+#ZS6&XN4)$@"```)Q@'SBW0D$(E<)%B)7"08
MBT0D.(M<)$")\<'F'L=$)!0`````#ZSY`HM\)"3'1"0D`````(G-BTPD2`GU
M@<+<O!N/B=X!T`GN(>LA\8G"BT0D&`G9B6PD.`'*B=&+5"0<B<;!X`6)RXE$
M)!"+;"00#ZS6&XN4)%`"``"+1"1`"?6+="0@`>N+;"0XB5PD2(E<)!")\<'F
M'@^L^0*)SXM,)%@)]X'"W+P;CXG^`=")^PGN(>N)PB'QBT0D$(E\)$")S8M\
M)!P)W0'JB<;!X`6)T8M4)!2)1"0@BVPD((G+#ZS6&XN4)%@"```)]8MT)!@!
MZXML)$B)7"0@B5PD6(GQP>8>#ZSY`HGPB<X)QHM$)#B!PM;!8LJ)="08`=`S
M="1`,?6)Z0'!BT0D((M4)"2)R\=$)!P`````B<;!X`4/K-8;BU0D%,=$)!0`
M````"<:+1"00`?,Q_XE<)$B)WHM<)!B)P<'@'@^LT0*+E"1@`@``B<T)Q8M$
M)$"!PM;!8LJ);"0X`=`QZXML)%B+5"0D,=V)Z0'!B?`/K/@;B40D$(GPBVPD
M$,'@!8E$)$`+;"1`BT0D(`'IB4PD$(E,)$")P0^LT0+!X!Z+E"1H`@``B<T)
MQ8M$)!B!PM;!8LJ);"0@`=`S;"0XBU0D%#-L)$B)Z0'!BT0D$`^LT!N)\HE$
M)!B+1"00BVPD&,'@!8E$)$@+;"1(`>G!YAX/K/H"B?")3"1(B4PD&(G6BY0D
M<`(``(ML)$`)QHM$)#B)="0X@<+6P6+*`=`S="0@BU0D'#'UB>D!P8M$)!B)
MRXG&P>`%#ZS6&XM4)!3'1"04``````G&BT0D$`'S,?^)WHE<)$"+7"0XB<'!
MX!X/K-$"BY0D>`(``(G-"<6+1"0@@<+6P6+*B6PD(`'0,>N+;"1(BU0D'#'=
MB>D!P8GP#ZSX&XE$)!")\(ML)!#!X`6)1"1("VPD2(M$)!@!Z8E,)!")3"1(
MB<$/K-$"P>`>BY0D@`(``(G-"<6+1"0X@<+6P6+*B6PD.`'0,VPD((M4)!0S
M;"1`B>D!P8M$)!`/K-`;B?*)1"08BT0D$,'@!8E$)$"+;"08"VPD0,=$)!P`
M`````>G!YAZ+;"1(#ZSZ`HGPB4PD0(E,)!B)UHN4)(@"```)QHM$)"")="0@
M@<+6P6+*`=`S="0XBU0D'#'UB>D!P8M$)!B)RXG&P>`%#ZS6&XM4)!3'1"04
M``````G&BT0D$`'S,?^)WHE<)$B+7"0@B<'!X!X/K-$"BY0DD`(``(G-"<6+
M1"0X@<+6P6+*B6PD.`'0,>N+;"1`BU0D'#'=B>D!P8GP#ZSX&XE$)!")\(ML
M)!#!X`6)1"1`"VPD0(M$)!@!Z8E,)$")3"00B<$/K-$"P>`>BY0DF`(``(G-
M"<6+1"0@@<+6P6+*B6PD(`'0,VPD.#-L)$B+5"04QT0D'`````")Z0'!BT0D
M$`^LT!N)\HE$)!B+1"00BVPD&,'@!8E$)$@+;"1(`>G!YAZ+;"1`#ZSZ`HGP
MB4PD2(E,)!B)UHN4)*`"```)QHM$)#B)="0X@<+6P6+*`=`S="0@BU0D'#'U
MB>D!P8M$)!B)RXG&P>`%#ZS6&XM4)!3'1"04``````G&BT0D$`'S,?^)WHE<
M)$"+7"0XB<'!X!X/K-$"BY0DJ`(``(G-"<6+1"0@@<+6P6+*B6PD(`'0,>N+
M;"1(,=V)Z0'!B?`/K/@;B40D$(GPBVPD$,'@!8E$)$@+;"1(`>F)3"1(B4PD
M$(M$)!B+5"0<QT0D'`````")P<'@'@^LT0*+E"2P`@``B<T)Q8M$)#B!PM;!
M8LJ);"0X`=`S;"0@BU0D%#-L)$")Z0'!BT0D$`^LT!N)\HE$)!B+1"00BVPD
M&,'@!8E$)$`+;"1``>G!YAZ+;"1(#ZSZ`HGPB4PD0(E,)!B)UHN4)+@"```)
MQHM$)"")="0@@<+6P6+*`=`S="0XBU0D'#'UB>D!P8M$)!B)RXG&P>`%#ZS6
M&XM4)!0)QHM$)!`!\S'_B=Z)7"1(BUPD((G!P>`>#ZS1`HN4),`"``")S0G%
MBT0D.('"UL%BRHEL)#@!T#'KBVPD0#'=B>D!P8GP#ZSX&XE$)!")\,'@!8E$
M)$"+;"00"VPD0(M$)!B+5"0<QT0D%`````#'1"0<``````'IB4PD$(E,)$")
MP0^LT0+!X!Z+E"3(`@``B<T)Q8M$)""!PM;!8LJ);"0@`=`S;"0XBU0D%#-L
M)$B)Z0'!BT0D$`^LT!N)\HE$)!B+1"00BVPD&,'@!8E$)$@+;"1(`>G!YAZ+
M;"0@#ZSZ`HGPB4PD&(E,)$B)UHN4)-`"```)QHM$)#B)="0X@<+6P6+*`=`Q
M]8M4)!R)[HML)$`Q]8GI`<&+1"08B<N)QL'@!0^LUAN+5"04"<:+1"00`?,Q
M_XE<)%B)WHG!P>`>#ZS1`HN4)-@"``")S8N,)-P"``#'1"0D``````G%BT0D
M(('"UL%BRHEL)$"#T0")RXG1,=(!R!':BUPD.#'KBVPD2#'=,=N)Z0'!B?`1
MTS'2#ZSX&XE$)!")\(ML)!#!X`6)1"0@"VPD((M$)!@!Z1'3B<J)P8E4)"")
M5"1(P>`>BU0D'(E<)$P/K-$"BY0DX`(``(G-BXPDY`(```G%BT0D.('"UL%B
MRHEL)!B#T0")RXG1,=(!R!':,VPD0#';,VPD6(GI`<&+1"0@$=.+5"0D#ZS0
M&XM4)"2)1"00BT0D((ML)!`/I,(%P>`%B40D.`ML)#B)5"0\,=(!Z1'3B<J)
M5"18B50D$(GR#ZSZ`L'F'HE<)%S'1"04`````(GPB=:+E"3H`@``"<:+1"1`
MBVPD2(ET)#B+7"04@<+6P6+*`=`S="08BU0D%#'UB>D!P8M$)!")QL'@!0^L
MUAN+5"0D"<:)\`'(,?^)QHM$)"")P<'@'@^LT0*+5"00B<V+3"04"<6+1"08
MB6PD2`^LR@+!Z0*)3"0DBTPD$(E4)""+E"3P`@``#Z3+'L'A'H'"UL%BRHE<
M)!2+7"0X`=")3"00B?HQZXML)%@QW8GI`<&)\,'J&P^L^!N)5"0<B?J)1"08
MB?"+;"08P>`%B40D0`ML)$`/I/(%B50D1(GH`<B)P0-,)"B+1"1HB</'0`0`
M````B0B+!"2+;"0@QT,,`````,=#%`````#'0QP``````?`+;"00QT,D````
M`(E#"(GH`T0D"(E#$(M$)$@#1"0PB4,8BT0D.`-$)%")0R"+A"3\`@``93,%
M%````'4+@<0,`P``6UY?7</H/]3__^L-D)"0D)"0D)"0D)"0D(7`#X2;````
M55=64X/L'(L-0$$%"(7)B4PD"'15#[8(@/D]=%N$R717B<.#PP$/M@N`^3UT
M!(3)=?$IPXM,)`B+*87M="R)5"0,B<:)SV:0@^P$4U95Z,76__^#Q!"%P'4'
M@'P=`#UT'X/'!(LOA>UUWH/$'#'`6UY?7<.-="8`,=OKN(UT)@")^BM4)`B+
M1"0,P?H"B1"#Q!R-1!T!6UY?7<,QP,.-=@"-O"<`````4XG#@^P89:$4````
MB40D##'`C50D"(G8Z#/___^%P'0ZC;0F`````*%`004(BU0D"(T4D(M*!(7)
MB0ITU8UV`(/"!(M*!(7)B0IU](U4)`B)V.CY_O__A<!US8M$)`QE,P44````
M=06#Q!A;P^@.T___C;0F`````(V\)P````!55XG'5E.)TX/L.&6A%````(E$
M)"@QP#'`@#H]#Y3``<-3Z#G4__^#Q!")Q8GXC50D&.B9_O__A<")Q@^$]P``
M`(/L#%#H%M3__X/$$#G%#X;+````BT0D&(T,A0`````/M@<\/0^$@P$``(3`
M#X1[`0``B?CK#8GVC;PG`````(32=`N#P`$/MA"`^CUU\2GXC40H`H/L#(LU
M0$$%"%`!SNA*T___@\00A<")!@^$3@$``*%`004(BU0D&(U/`8L4D`^V!X3`
MB`)U%>L7C78`@\$!#[9!_X/"`83`B`)T!#P]=>S&`CTQP(VT)@`````/M@P#
MB$P"`8/``83)=?$QP(M\)!QE,ST4````#X7Y````@\0L6UY?7<.-M@````"#
MPP$/MD/_@\8!A,"(1O]U[^O,D(UT)@"+%4!!!0B+`H7`#X2M````,?:-M@``
M``"#Q@&+!+*%P'7VC02U"````(L-@%$%"(7)=#6#[`A04NAKTO__@\00A<"C
M0$$%"`^$?````(T,M0````#'1+`$`````(ET)!CIP_[__XUV`(E4)`B#[`S'
M!8!1!0@!````4.@YTO__@\00A<!T0XT,M0````"#[`11BU0D$(E,)!12B40D
M%%#HI-#__XM$)!B#Q!"+3"0,HT!!!0CKGC'`Z9S^__^X"````#'VZ6#___^X
M_____^GV_O__Z/#0__]55U93B<:![(P```!EH10```")1"1\,<"%]G0%@#X`
M=1^+1"1\93,%%`````^%'P$``('$C````%M>7UW#C78`@^P,5NCWT___@\00
MA<")QW3/C;8`````@^P,5^A/T___@\00A<")PP^$N@```(![$RX/A(@```"#
M[`R-:Q-6Z,S1__^)+"2)1"0<Z,#1__^+3"0<C40!`HD$).A`T?__B<-86E56
M:-#?!`AJ_VH!4^B;T___@\0<C40D(%!3:@/H*]/__X/$$(/X_W00BT0D+"4`
M\```/0!```!T:X/L#%/H*M#__X/$$(/L#%/HCL___X/$$.E>____C;8`````
M#[9#%(3`#X1,____/"X/A63___^`>Q4`#X0Z____Z57___^0C70F`(/L#%?H
M_]+__XDT).B'S___@\00Z>#^__^-M"8`````B=CHL?[__^N8Z)K/__^-=@"-
MO"<`````5E.#[!#_-5!!!0CHD-+__XN`@````%N+<`3_-5!!!0CH>]+__P^V
M6&58_S50004(@^-_Z&C2__^+0`0/MT`0P>`'"<-FB5X"6/\U4$$%".A,TO__
MBX"`````BU@$6/\U4$$%".@WTO__@\0,:@!HI>$$"%#HI]#__XE#'%C_-5!!
M!0CH&-+__XN`@````(M8!%C_-5!!!0CH`]+__XN`T`,``(E#(%C_-5!!!0CH
M[M'__XN`@````%J+6`3_-5!!!0CHV='__XN(\````(/$$#'2A<ET&H/L#/\U
M4$$%".B\T?__BX#P````@\00BU!P@^P,B5,D_S50004(Z)_1__^+@(````"+
M0`3'0"@`````6/\U4$$%".B#T?__BX"`````BT`$QT`8`````%K_-5!!!0CH
M9]'__XN`@````%F+6`3_-5!!!0CH4M'__XN`_`$``(E#+(/$%%M>PXUV`%.)
MPX/L%/\U4$$%".@OT?__C9#\````@\0,4E-J`^@MT?__@\00A<!T#H/$"#'`
M6\.-M"8`````@^P,_S50004(Z/K0__^+@`P!``"#Q!`E`/```#T`0```=".#
M[`S_-5!!!0CHU]#__XN`#`$``(/$$"4`\```/0"@``!UK(/L"&H"4^@'T/__
M@\00A<`/E,"#Q`@/ML!;PXVT)@````!55XG'5E.)U8'L(!```&6A%````(F$
M)!`0```QP&C_#P``C70D%%9HUM\$".BOS?__@\00A<!^8(U8_X!\'`P`=$Z)
MPX/L!%-J+U;H0,___X/$$(7`=$&#[`S_-5!!!0CH.]#__U-65U#HPL___X/$
M((N$)`P0``!E,P44````=36!Q!P0``!;7E]=PXUT)@"%VW6PC70F`(/L#/\U
M4$$%".CZS___@\0,55=0Z#_-__^#Q!#KN^C5S/__D(UT)@"#[!C_-5!!!0CH
MTL___VC6X00(:#"3!`AHY=\$"%#H7<[__X/$+,.)]HV\)P````"#[!C_-5!!
M!0CHHL___XD$).BZ____6/\U4$$%".B.S___6EEJ`&BEX00(:*7A!`AHH-H$
M"&@!X`0(4.BPSO__@\0LPXVV`````(V_`````%=64X'L$"```&6A%````(F$
M)`P@```QP.CSS/__@^P(:.'?!`A0:!;@!`AH`1```&H!C5PD)E/H=,___X/$
M((7`>&6#[`1H`!```(V\)!,0``!74^A'S/__@\00A<")QGA&C4`!@^P,4.C2
MS/__@\00A<")PW0Q@^P$5E=0Z&[+___&!#,`@\00B=B+E"0,(```93,5%```
M`'41@<00(```6UY?PXUV`#'`Z]_HG\O__^L-D)"0D)"0D)"0D)"0D.D[____
MC70F`(V\)P````!55U93@>PL$```BYPD0!```(U4)!B+O"1$$```9:$4````
MB80D'!```#'`N"3@!`CH&_?__X/L"(G&:B]3Z'[,__^#Q!"%P'0MB=JX+>`$
M".@K^/__B=B+C"0<$```93,-%`````^%3`$``('$+!```%M>7UW#@^P,4^AA
MS/__6EF)1"04:#K@!`A7Z&#-__^#Q!")Q8M$)`R-?"0<@\`!B40D#(UT)@"%
M[72=@'T``+@BX`0(#T3HA?9T%8/L"%56Z`K*__^#Q!"%P`^$G@```(/L#%7H
M!LS__X/$$(!\!?\O=1.-="8`@^@!@'P%_R_&1`4``'3QBTPD#(T4`8'Z_P\`
M``^//____X/L!%-H/.`$"%5H8.$$"&@`$```:@%7Z+K-__^#Q!3_-5!!!0CH
M7,W__X/$#`7\````4%=J`^@[S?__@\00A<!U(X/L#/\U4$$%".@VS?__BX`,
M`0``@\00)0#P```]`(```'09@^P(:#K@!`AJ`.ARS/__@\00B<7I(/___X/L
M"&H!5^A-S/__@\00A<!UU8GZN"W@!`CHVO;__X/L#%?HH<O__X/$$.F@_O__
MZ,3)__^-="8`BT0D!`^V"(3)=!6-4`%FD(#Y+P^V"@]$PH/"`83)=?#SPXVT
M)@````"-O"<`````4X/L&(M<)""%VW1<#[83A-)T58A4)`^#[`Q3Z-#*__^-
M1`/_@\00#[94)`\YPW(/ZRJ-M@````"#Z`$YV'0=@#@O=/3K#XUV`(V\)P``
M``"`."]T0(/H`3G#<O0YPW4U@/HO=7*-=@"#[`QJ`N@.RO__@\00A<!T5[HN
M````9HD0@\086\.-=@"-O"<`````@#@O=0>#Z`$YPW+T*=B-4`*!^@`0``!W
M)X/``6@`$```4%-H@$$%".@#R___@\00N(!!!0B#Q!A;PXVV`````(/$&#'`
M6\/'1"0@/.`$"(/$&%OI>,K__Y"-M"8`````5U:#[#1EH10```")1"0L,<"A
MM.$$"(E$)`JAN.$$"(E$)`ZAO.$$"(E$)!*AP.$$"(E$)!:AQ.$$"(E$)!JA
MR.$$"(E$)!ZAS.$$"(E$)"*AT.$$"(E$)"8/MP74X00(9HE$)"JX/N`$".BQ
M]/__N$?@!`CHI_3__[A/X`0(Z)WT__^X6.`$".B3]/__N%_@!`CHB?3__[AO
MX`0(Z'_T__^X).`$".AU]/__N'O@!`CH:_3__[B%X`0(Z&'T__^XC^`$".A7
M]/__N"W@!`CH3?3__[B9X`0(Z$/T__^XHN`$".@Y]/__C50D!+BMX`0(Z'OS
M__^%P'0,B<*XA>`$".B;]/__C50D!+B^X`0(Z%WS__^%P'0,B<*XT.`$".A]
M]/__C50D!+C;X`0(Z#_S__^%P'0SB<*X).`$".A?]/__N@?A!`BX7^`$".A0
M]/__BT0D+&4S!10```!U58/$-%Y?PY"-="8`C50D!+CKX`0(Z/KR__^%P'06
MB<*X>^`$".@:]/__Z[F0C;0F`````(UT)!N__.`$"+D*````\Z9UGXU4)"6X
M>^`$".CP\___ZX_HZ<;__XGVC;PG`````(/L'&6A%````(E$)`PQP*$@004(
M@_C_=!>+3"0,93,-%````'4^@\0<PXVV`````(U4)`BX>^`$".AR\O__A<!T
M'@^V$(32#Y7`@/HP#Y7"#[;2(="C($$%".N]C70F`#'`Z_'H=\;__XVT)@``
M``"#[`SH>,;__X/L#%#HS\7__X/$$(7`=`B+`(/$#,-FD#'`Z_:-M@````"-
MOP````!55[\3X00(5E.[">$$"(/L3(ML)&#'1"0@$^$$"(UT)"AEH10```")
M1"0\,<#'1"0D">$$",=$)"@6X00(QT0D+`SA!`C'1"0P$>$$",=$)#0CX00(
MQT0D.`````#K(Y"#[`A54(E$)!CH$L7__X/$$(7`=$N%VW0JBP:)WX/&!(G#
MC50D'(GXZ(/Q__^%P'0%@#@`=<J)ZHGXZ*'R__^%VW76BT0D/&4S!10```!U
M<8/$3%M>7UW#D(VT)@````"#[`Q5Z-?&__^+3"08B40D'(D,)(E,)!CHP\;_
M_XM4)!R-1`("B00DZ$/&__^#Q`R+3"0,46@ZX`0(56A@X00(:O]J`5")1"0H
MZ)+(__^#Q""+5"0(B?CH)/+__^E4____Z!K%__^-=@"-O"<`````55=64X'L
M'($``(N$)#"!``"-5"0<QT0D(#KA!`C'1"0D(N`$",=$)"@`````QT0D.-#@
M!`C'1"0\R>`$"(D$),=$)$`_X00(9:$4````B80D#($``#'`N"3@!`C'1"1$
MYN`$",=$)$A'X00(QT0D3`````#'1"0L+N$$",=$)#!+X00(QT0D-`````#H
M3_#__X7`=`F`.``/A0($``#H_?W__X7`B<,/A!0$``"#[`Q3Z+K%__^-1``!
M@\00@^P,4.@ZQ?__@\00@#L`B<:)QW0JC;8`````#[8#@^P,@\,!4&A4X00(
M:O]J`5>#QP+H?,?__X/$((`[`'7<C7PD/+C0X`0(ZQ.)]HV\)P````"#QP2+
M1_R%P'0VC50D'.B][___A<")PW3G@#@`=.+HK?7__X7`=-F#[`Q3Z*#%__^#
MQ!"%P(G%=5F-M"8`````BUPD((7;=$B`.P"_`0```'46ZSR-="8`BUR\((7;
M=#"#QP&`.P!T*(G8Z&'U__^%P'3E@^P,4^A4Q?__@\00A<!TU8G%ZPN)]HV\
M)P`````Q[8/L#(GS5>C#Q/__@\00BPN#PP2-D?_^_O[WT2'*@>*`@("`=.F)
MU\'O$/?"@(````]$UXU[`@]$WP#2@]L#@^P,*?.-G`,$!```4^@.Q/__B40D
M&%:)QFA9X00(:#S@!`A5:%[A!`AJ_VH!4.A=QO__@\0H:,`!``!6Z*_$__^#
MQ!"#^/]T;X/L#/\U4$$%".CIQ?__@\0,!?P```!0_W0D$&H#Z.7%__^#Q!"%
MP'1N@^P,_W0D%(M$)!#_,&@<X@0(:@'_-4A!!0CH;\7__X/$(#'`BXPD#($`
M`&4S#10````/A:@)``"!Q!R!``!;7E]=PXUV`.ACQ/__BP"#^!%TA8/L"%#_
M="04BT0D$/\P:.#A!`CKJXVT)@````"#[`S_-5!!!0CH4L7__XN`#`$``(/$
M$"4`\```/0!````/A6O___^#[`S_-5!!!0CH*\7__XNP%`$``.@@PO__@\00
M.<8/A4?___^#[`S_-5!!!0CH!\7__XN`#`$``(/$$"7_`0``/<`!```/A2#_
M__^#[`Q3Z,7"__^-5"0LB40D'+@,X00(Z)/M__^#Q!"%P`^$N`@``(/L#%#H
M?\/__UI94(M$)`S_,.@A]O__@\00A<")PP^$E`@``(/L#%/HZ\+__X/$$(/X
M`WXKC70#_+]GX00(N04```#SIG49@_@$#X36!@``@'P#^R\/A,L&``"0C70F
M`.AS^O__A<!U&H/L"&H`4^C$PO__B40D$(/$$(7`#X4U`0``N@?A!`BX>^`$
M"#';Z"3N___HW\'__VBEX00(4&@\X`0(BWPD%%=H@.$$"&K_:@&+="0H5NA<
MQ/__@\0@ZSN-M"8`````Z-O"__^#.!%U0.BAP?__@\,!@^P,:*7A!`A34&@\
MX`0(5VB.X00(:O]J`5;H'\3__X/$,(/L"&C``0``5NANPO__@\00@_C_=+:#
M[`S_="04Z"K`__^+="0<N"3@!`B)\NB*[?__B30DZ$+Z__^#Q!")\.G>_?__
MD(VT)@````"#[`Q0B40D&.@C^O__BT0D&(D$).@GPO__@\00Z;7]__^X+N$$
M"+X!````ZPZ-=@"+1+0L@\8!A<!T*8U4)!SH_.O__X7`=.B`.`!TXX/L#%#H
MZL'__X/$$(7`=-.)P^FI^___L`V[,^$$".FM^___:@)J_VKNBW0D#%;HH,#_
M_X/$#&H&C80D%`$``%!6Z#V___^#Q!"`O"0,`0```'4.@+PD#0$``$,/A"X&
M``!J`&H`:@#_="0,Z&/`___'1"1@`2-%9\=$)&0`````QT0D:(FKS>_'1"1L
M`````,=$)'#^W+J8QT0D=`````#'1"1X=E0R$,=$)'P`````QX0D@````/#A
MTL/'A"2$`````````,>$)(@`````````QX0DC`````````#'A"20````````
M`,>$))0`````````QX0DV`````````"#Q!"-=@"#[`1H`(```(V$)!0!``!0
M_W0D#.AGOO__@\00A<")Q0^.ZP$``(M,)'B+7"1\B>B)[\'@`XGNP?\?`<B#
M^P`/A[,!```YP0^'JP$``(N,)(````"+G"2$````#ZS^'8E$)'B+A"3(````
MP>\=`?''1"1\`````!'[B8PD@````(7`B9PDA`````^$60$``+]`````*<>-
MA`2(````.?T/3OV#[`17C8PD%`$``%%0Z`R^__^+A"38`````?B)A"38````
M@\00@_A`#X4P____C80D#`$``"G]`<>-1"10Z,S$__^-="8`@_T_#X[3````
MB>Z)^XUV`(L#@^Y`@\-`B80DB````(M#Q(F$)(P```"+0\B)A"20````BT/,
MB80DE````(M#T(F$))@```"+0]2)A"2<````BT/8B80DH````(M#W(F$)*0`
M``"+0^")A"2H````BT/DB80DK````(M#Z(F$)+````"+0^R)A"2T````BT/P
MB80DN````(M#](F$)+P```"+0_B)A"3`````BT/\B80DQ````(U$)%#H"L3_
M_X/^/P^/2?___X/M0(GHP>@&C5`!P>`&*<7!X@8!UVI$55>-A"24````4.A;
MOO__B:PDV````(/$$.D<_O__C70F`(V\)`P!``#I]/[__XUT)@"+C"2`````
MBYPDA````(/!`8/3`.E*_O__@^P,_W0D#.@SP/__BX0DD````(N<)(@```"+
MM"2,````BY0DE````(E$)!")V`^L\`.)5"04B<*#XC^-0@'&A!28````@(/$
M$(/X.`^/9@(``+@W````C8P4@0```"G0@_@$C5$(#X.5`@``A<!T#*@"QD$(
M``^%G0,``(L\)(ML)`2(G"3'````B?@/K.@8B(0DP````(GX#ZSH$(B$),$`
M``")^`^LZ`B-K"3C````B(0DP@```(GXC;PDT````(B$),,```")V`^L\!B(
MA"3$````B=@/K/`0B(0DQ0```(G8#ZSP"(B$),8```"-1"10Z*?"__^+1"10
MBU0D5(M<)%R)P8B$)-(````/K-$8B<Z(C"3/````B<$/K-$0B(PDT````(G!
M#ZS1"(B,)-$```"+3"18B<B(C"36````#ZS8&(B$)-,```")R`^LV!"(A"34
M````B<B+3"1@#ZS8"(M<)&2(A"35````B<B(C"3:````#ZS8&(B$)-<```")
MR`^LV!"(A"38````B<B+3"1H#ZS8"(M<)&R(A"39````B<B(C"3>````#ZS8
M&(B$)-L```")R`^LV!"(A"3<````B<B+3"1P#ZS8"(M<)'2(A"3=````B<B(
MC"3B````#ZS8&(B$)-\```")R`^LV!"(A"3@````B<@/K-@(C9PD"P$``(B$
M).$```")\.D/````B?:-O"<`````#[8'@\<!@^P,#[;`4&A4X00(:O]J`56#
MQ0+H,;[__X/$(#G===K&A"0+`0```&BEX00(C80DYP```%!H/.`$"/]T)!1H
M<>$$"&K_:@'_="0HZ/J]__^#Q"#I[/G__XL$)(MH!(7M#X0L^?__@^P,5>C;
MN___@\00@_@##X87^?__C70%_+]LX00(N04```#SI@]$W>G_^/__N#\````I
MT(G!C804@0```(/Y!(U0"'-NA<ET#?;!`L9`"``/A40!``"-1"10Z+7`__^-
ME"2(````N0X````QP(G7\ZOI>_W__\=!"`````"#P0S'1!#\`````(/A_"G*
M`<*#XOR#^@0/@E;]__^#XOPQP,<$`0````"#P`0YT'+RZ3[]__^->`S'0`@`
M````B=#'1!'\`````(/G_"GX`<B#X/R#^`1R@(/@_(G!,<#'!`<`````@\`$
M.<AR\NEF____@+PD#@$``$$/A<3Y__^`O"0/`0``0P^%MOG__X"\)!`!``!(
M#X6H^?__@+PD$0$``$4/A9KY__]J`FK_:L:+="0,5NC\N?__@\0,:BF-A"04
M`0``4%;HF;C__VBEX00(C80D(`$``%!H/.`$"/]T)"1H<>$$"&K_:@'_="0X
MZ'&\__^#Q##I8_C__XGVC;PG`````(L$)(L8Z6+W__\Q_V:)?!#^Z5?\__\Q
M[6:);!'^Z;#^___HV;C__XGVC;PG`````%575E.#["AEH10```")1"08,<#_
M-5!!!0CHPKO__XU4)!C&0&$!N%_@!`CH<.3__X/$$(7`=`F`.#$/A%`"``#H
MZ^___X/L#/\U4$$%".B-N___:@MJ`6B?X00(4.ANN?__@\0@A<`/A+,```"#
M/8A1!0@!BT`,BW@8#XZ@````,?:[`0```.LQC;0F`````(M%#(/L"%"AA%$%
M"/\TF.A\M___@\00A<!U9:&(404(@\,!@\8!.=A^6X/L#/\U4$$%".@8N___
M:@!65U#H?KK__X/$((7`=#>+*(M%""4`!"``/0`$``!TIH/L#/\U4$$%".CH
MNO__:@)J`%50Z#VX__^#Q"#KBY"-M"8`````H8A1!0B-4/\Y\@^$,`$``(/L
M#/\U4$$%".BRNO__:@-J`6BDX00(4.B3N/__@\0@A<")PW0TBT`,@^P,BS#_
M-5!!!0CHA[K__X/$#&BFX00(5E#HR+?__XM##(/$$(L8]D,*0`^%$`(``(/L
M#/\U4$$%".A8NO__:@-J`6BKX`0(4.@YN/__@\0@A<")QG0YC50D"+@MX`0(
MZ/+B__^%P(G##X1H`0``BT8,@^P,BSC_-5!!!0CH%;K__X/$#%-74.A:M___
M@\00@^P,_S50004(Z/FY__^-5"08QD!A`+@DX`0(Z*?B__^#Q!"%P(G#HXQ1
M!0@/A)4```"#[`AHP`$``%#H=[C__XU0`8/$$(/Z`78)@_@1#X6.`0``BT0D
M#&4S!10````/A7@!``"#Q!Q;7E]=PXUV`(V\)P````"#^`$/CL?^__^[`0``
M`&:0@^P,_S50004(@\,!Z&^Y__]>75=0Z`:V__^#Q!`Y'8A1!0A_V^F6_O__
MC;8`````@'@!``^$J_W__^FA_?__D(/L#/\UA%$%".@2\?__@\00A<"CC%$%
M"`^$ZP```(M&#(L]A%$%"(L8BT,()0`$(``]``0```^%C0```(M##(/L"%=0
MZ">V__^)QXM&#(/$$(L8BU,(@>(`!"``@?H`!```=4>+0PQ74*&$404(_S!H
ME.($".A6M___C;8`````H811!0B#[`R+.(M&#(L8_S50004(Z*:X__^)^HG8
MZ/WG__^#Q!#ICO[__X/L#/\U4$$%".B'N/__:@)J`%-0Z-RU__^#Q"#KGH/L
M#/\U4$$%".AIN/__:@)J`%-0Z+ZU__^#Q"#I5?___X/L#/\U4$$%".A(N/__
M6EE34.A/M___@\00Z=']__^#[`QH<.($".BZMO__Z!6U__]0H811!0A3_S!H
MO.($".BBMO__9I!64X/L$(MT)!Q6Z&'K__\/M@B#Q!")PX3)=!6-4`%FD(#Y
M+P^V"@]$VH/"`83)=?#HZ^W__X7`=!Z%]G0:@#X`=!6#[`AH6>$$"%/H\+/_
M_X/$$#G8=`:#Q`1;7L.#Q`2)\%M>Z:?C__^-M"8`````@^P8_S50004(Z)*W
M__]:66K_4.@(M?__6/\U4$$%".A\M___@\0,:@!HX,,$"%#H/+?__X/$',-F
MD&:09I!FD%/H"KK__X'#VF```(/L"/^S'`$``/]T)!S_="0<_W0D'.C*M/__
M@\086\-FD&:0D%57,?]64^C5N?__@<.E8```@^P,BVPD((VS_/[__^@!L___
MC8/X_O__*<;!_@*%]G0CC;8`````@^P$_W0D+/]T)"Q5_Y2[^/[__X/'`8/$
M$#GW=>.#Q`Q;7E]=PXUV`//#``!3@^P(Z'.Y__^!PT-@``"#Q`A;PP,````!
M``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`"X`4$%2
M7U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU
M3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!0
M05)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q
M`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!54T52`%-9
M4U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S
M)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM`````%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@``!P97)L>'-I+F,`)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&5X96-U
M=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.
M5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@
M/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'
M0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@
M*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*<V5E:R!?1D@L("TX+"`R.PIR96%D(%]&2"P@)&)U9BP@.#L*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["G-E96L@7T9(+"`M,3(L
M(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+3$R("T@=6YP86-K
M*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68[
M"F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@
M*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF
M("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO
M<V4@)&]U=#L*8VAM;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF
M("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]
M+R1B87-E;F%M921E>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO
M9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E
M('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@
M)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L
M(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I
M(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@
M)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@
M9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*
M;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI
M.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE
M;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I
M;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D
M9FEL96YA;64M/GMC<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*
M<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P
M96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I
M;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I
M;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@
M=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N
M(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A
M(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E
M9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^(&QE
M;F=T:"@D82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D
M9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R('9A
M;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD
M9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*
M?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@
M*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N
M;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ
M<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I
M;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%
M+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB
M:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M
M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT
M*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO
M;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H
M)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N
M,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*
M96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*
M8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D[
M"GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<
M;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE
M*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-
M4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$[
M"FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%2
M7U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ
M<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R
M86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?
M+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M
M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*
M<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E
M('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO
M;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H
M)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N
M,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X
M*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G
M;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*
M?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA
M<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@
M*"1E>'0L("1C<F,I(#T@0%\["FUY("@D9F@L("1F:6QE;F%M92D["B1F:6QE
M;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PII9B`H)$5.5GM005)?0TQ%
M04Y]*2!["G5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PIP=7-H
M($!T;7!F:6QE+"`D9FEL96YA;64["GT*96QS92!["G)E='5R;B`H=6YD968L
M("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["GT*;W!E;B`D9F@L("<^
M)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FXH
M)&9H+"`D9FEL96YA;64I.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\
M?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]
M("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O
M.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R
M;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%
M?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T
M0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?
M<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=0
M05)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M(&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?
M8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY
M("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%
M04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!
M4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I
M970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E
M('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#
M;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD[
M"GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<
M)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q
M<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G
M;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?
M15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````````(#____/00$;`SOH
M````'````)!S__\$`0``T'?___`-``#P>O__*`$``#"@__]L`0``X*#__]`!
M``!@H?__]`$``'"C__]T`@``T*3__RP#```PIO__N`,``-"F__\4!```D*?_
M_[`$``#`I___V`0``!"H__\0!0``T*C__YP%``#@J/__L`4``*"J__^L!@``
MT*K__\`&``#`J___(`<``("M__]0!P``\*W__VP'```@KO__D`<``%"O__\`
M"```D+O__]P+``!@O___;`T``-"___^X#0``$,#__S`.``!`P/__7`X``*#`
M__^H#@``%``````````!>E(``7P(`1L,!`2(`0``(````!P```"$<O__0`0`
M```."$8.#$H/"W0$>``_&CLJ,B0B0````$````#`>?__,24```!!#@B%`D$.
M#(<#0PX0A@1!#A2#!48.H`8#&R4*#A1!PPX00<8.#$''#@A!Q0X$00L```!@
M````A````+R>__^F`````$D."(4"00X,AP-!#A"&!$$.%(,%0PXP`D0.-$$.
M.$$./$$.0$@.,%<*#A1#PPX00<8.#$''#@A!Q0X$10M:#A1%PPX00<8.#$''
M#@A!Q0X$````(````.@````(G___<@````!!#@B#`D4.(`)E"@X(0<,.!$$+
M?`````P!``!DG___$`(```!!#@B%`D$.#(<#0PX0A@1!#A2#!44.3%<.4$@.
M0%H.3$$.4$@.0`)+#DQ'#E!*#D`";`H.%$'##A!!Q@X,0<<."$'%#@1'"P).
M#DA!#DQ!#E!(#D!O#DQ+#E!(#D!.#D1!#DA)#DQ%#E!,#D````"T````C`$`
M`/2@__]6`0```$$."(4"00X,AP-!#A"&!$$.%(,%2`Z@`6P*#A1!PPX00<8.
M#$''#@A!Q0X$1`M##JP!00ZP`4@.H`%/#JP!00ZP`4@.H`%7#JP!1`ZP`60.
MK`%!#J@!00ZL`4$.L`%%#K0!0@ZX`4(.O`%!#L`!2`ZD`44.J`%!#JP!0@ZP
M`4@.H`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.H`%V#JP!00ZP`5`.H`$`B```
M`$0"``"<H?__70$```!!#@B&`D$.#(,#0PX<1@X@3`X<20X@2@X<1@X@60X<
M1@X@3PX<1@X@2`X40@X810X<00X@20X<1@X@3PX<1@X@3PX<1@X@3`X<20X@
M3@X020X<1@X@3@X01@X<20X@5@X<1@X@5@X<1@X@3`X<20X@40X,0<,."$'&
M#@18````T`(``'"B__^9`````$$."(,"10X<1@X@3@X400X800X<0@X@2`X0
M1PH."$/##@1("T,.'$8.($X.$$\.'$8.($X.$$\.&$(.'$$.($@.$$@."$3#
M#@0``)@````L`P``M*+__[L`````00X(A0)!#@R'`T,.$(8$00X4@P5(#K0@
M5`ZX($4.O"!%#L`@2`ZP(%,.M"!!#K@@0@Z\($$.P"!(#K`@1PZ\($8.P"!&
M#L0@00[(($$.S"!!#M`@2`ZP(%8*#A1!PPX00<8.#$''#@A!Q0X$10M+#KP@
M1@[`($@.M"!!#K@@00Z\($$.P"!(#K`@`"0```#(`P``V*+__R<`````0PX<
M1@X@2@XD10XH10XL00XP2`X$```T````\`,``."B__]$`````$,.'$8.($X.
M'$8.($8.'$$.&$(.'$4.($4.)$4.*$4.+$$.,$@.!(@````H!```^*+__[$`
M````00X(AP)!#@R&`T$.$(,$1@Z@0%<.J$!%#JQ`00ZP0$4.M$!%#KA`0@Z\
M0$4.P$!(#J!`1PZD0$4.J$!(#JQ`00ZP0$@.H$!,#JQ`00ZP0$@.H$!)#J1`
M00ZH0$$.K$!!#K!`3`Z@0%@*#A!!PPX,0<8."$''#@1$"P``$````+0$```L
MH___!0````````#X````R`0``"BC__^\`0```$$."(4"00X,AP-!#A"&!$$.
M%(,%1@[`(&X.R"!$#LP@00[0($@.P"!L"@X40<,.$$'&#@Q!QPX(0<4.!$$+
M0P[,($$.T"!&#LP@00[(($D.S"!!#M`@2`[`(&P.R"!!#LP@00[0($@.P"!+
M#LP@00[0($@.P"!P#L0@00[(($4.S"!!#M`@10[4($4.V"!"#MP@00[@($@.
MS"!&#M`@2`[$($8.R"!!#LP@0@[0($@.P"!'#LP@1@[0($X.P"!/#L@@10[,
M($(.T"!(#L`@2@[(($(.S"!!#M`@2`[`(%,.S"!!#M`@2`[`(``0````Q`4`
M`.RC__\B`````````%P```#8!0``"*3__^@`````00X(@P)##B!6#BQ!#C!,
M#B`"1`XL0@XP2`X@3PH."$'##@1+"V$.)$$.*$$.+$4.,$@.($@*#@A!PPX$
M1PM#"@X(0\,.!$$+2PX(0<,.!"P````X!@``F*3__[<!````00X(AP)!#@R&
M`T,.0`-;`0H.#$'&#@A!QPX$1@L``!@```!H!@``**;__VD`````0PX@9@H.
M!$<+```@````A`8``'RF__\D`````$,.$$@.'$$.($@.$$D*#@1#"P!L````
MJ`8``(BF__\F`0```$$."(4"00X,AP-&#A"&!$$.%(,%2`Y@`E(.:$$.;$$.
M<$P.8`)""@X40<,.$$'&#@Q!QPX(0<4.!$D+0PYL00YP;`YD10YH10YL00YP
M10YT0@YX0@Y\00Z``4P.8```V`,``!@'``!(I___-PP```!!#@B%`D$.#(<#
M00X0A@1!#A2#!48.L(("`J8.O(("00[`@@),#K""`D,.O(("00[`@@)(#K""
M`E4.O(("1`[`@@)%#L2"`D(.R(("0@[,@@)!#M""`DL.L(("`D,.O(("00[`
M@@)(#K""`@)##KR"`D$.P(("2`ZP@@)6#KR"`D,.P(("2`ZP@@)S#KR"`DH.
MP(("2@[$@@)'#LB"`D4.S(("00[0@@)%#M2"`D(.V(("0@[<@@)!#N""`D@.
MN(("10Z\@@)!#L""`D@.L(("2`Z\@@)&#L""`D@.M(("1@ZX@@)$#KR"`D(.
MP(("2`ZP@@)'#KR"`D0.P(("1@[$@@)%#LB"`D(.S(("1@[0@@)(#K""`EP*
M#A1!PPX00<8.#$''#@A!Q0X$1`M/"@ZX@@)!#KR"`D0.P(("1@[$@@)%#LB"
M`DD+0PZ\@@)&#L""`DX.L(("4PZ\@@)&#L""`E,.L(("2PZ\@@)&#L""`DX.
ML(("4PZ\@@)!#L""`EH.L(("2PZ\@@)!#L""`D8.O(("00ZX@@)!#KR"`D8.
MP(("2`ZP@@)-#KR"`D$.P(("2`ZP@@)\#KB"`D(.O(("00[`@@),#K""`F,.
MM(("00ZX@@)%#KR"`D4.P(("10[$@@)"#LB"`D(.S(("10[0@@)(#K""`EX.
MO(("10[`@@)!#L2"`D$.R(("10[,@@)!#M""`D4.U(("0@[8@@)"#MR"`D$.
MX(("2`ZP@@)##KB"`D4.O(("00[`@@)(#K""`D@.O(("1`[`@@)@#K""`E(.
MO(("00[`@@)8#K""`G0.O(("00[`@@)(#K""`ED.M(("0@ZX@@)"#KR"`D4.
MP(("2`ZT@@)"#KB"`D@.O(("00[`@@)(#K""`EH.M(("0@ZX@@)"#KR"`D0.
MP(("`I4.L(("1@ZT@@)%#KB"`D@.O(("1`[`@@)(#K""`@*)#K2"`D$.N(("
M2`Z\@@)!#L""`E@.L(("`O\.M(("00ZX@@)!#KR"`D@.P(("3PZP@@)U#KR"
M`D0.P(("`D(.L(("`]\!#KR"`D0.P(("10[$@@)"#LB"`D(.S(("00[0@@)+
M#K""`E$.M(("2`ZX@@)%#KR"`D0.P(("10[$@@)"#LB"`D(.S(("1`[0@@)(
M#K""`E8.O(("00[`@@)(#K""`@,>`0ZT@@)"#KB"`D(.O(("10[`@@)(#K2"
M`D(.N(("2`Z\@@)!#L""`DH.Q(("2`[(@@)%#LR"`D0.T(("10[4@@)"#MB"
M`D(.W(("1`[@@@)(#K""`HP!``#T"@``K*___\X#````00X(A0)!#@R'`T$.
M$(8$00X4@P5##CQ2#D!:#C!5#CQ&#D!'#D1"#DA%#DQ!#E!(#C!Q#CA!#CQ(
M#D!(#C!6#CQ&#D!'#D1!#DA!#DQ!#E!(#C!8#CQ&#D!'#D1"#DA!#DQ!#E!(
M#C!=#CQ&#D!'#D1"#DA%#DQ!#E!(#C!,#CQ(#D!(#C1%#CA!#CQ!#D!+#C!/
M#CQ&#D!'#D1"#DA%#DQ!#E!(#C!D#CQ(#D!(#C1!#CA!#CQ!#D!(#C!##CQ&
M#D!:#C!2#CA%#CQ!#D!+#C!B"@X40<,.$$'&#@Q!QPX(0<4.!$L+4PX\1@Y`
M20X\00XX00X\00Y`2`XP9@X\1@Y`2`XP<0XX00X\00Y`30XP5PH.-$$..$<.
M/$4.0$L+2`X\30Y`40XP2`X\1@Y`1PY$0@Y(00Y,00Y02`XP10X\1@Y`1PY$
M0@Y(00Y,00Y02`XP2`X\1@Y`1@X\00XX00X\00Y`2`XP2`H./$4.0$4+1@XT
M1@XX0@X\10Y```!(````A`P``.RQ__]I`````$$."(8"00X,@P-##AQ%#B!+
M#A!P#AA%#AQ!#B!(#A!'"@X,0<,."$'&#@1!"T,.#$/##@A!Q@X$````-```
M`-`,```0LO__.`````!##AQ&#B!&#AQ!#AA"#AQ!#B!&#AQ&#B!(#A1"#AA%
M#AQ!#B!(#@0\````"`T``-AI__\B`@```$0,`0!'$`4"=0!%#P-U=`80!@)U
M?!`#`G5X`Z,!"L$,`0!!PT'&0<5##`0$00L`*````$@-``#8L?__*P````!!
M#@B#`DX.$$8.%$0.&$0.'$0.($@."$'##@1(````=`T``-RQ__]=`````$$.
M"(4"00X,AP-##A"&!$$.%(,%3@X@9PXD1`XH1`XL00XP30X@1PX40<,.$$'&
M#@Q!QPX(0<4.!```$````,`-``#PL?__`@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#0F00(L)D$"``````!`````0````$````%`@``
M`0```%0"```,````=)($"`T```"TWP0(&0```/@^!0@;````!````!H```#\
M/@4('`````0```#U_O]OK($$"`4```"HB00(!@````B#!`@*````'04```L`
M```0````%0`````````#`````$`%"`(````8`@``%````!$````7````7)`$
M"!$````LD`0($@```#`````3````"````/[__V^<CP0(____;P(```#P__]O
MQHX$"```````````````````````````````````````````````````````
M```````````````$/P4(``````````"VD@0(QI($"-:2!`CFD@0(]I($"`:3
M!`@6DP0()I,$"#:3!`A&DP0(5I,$"&:3!`AVDP0(AI,$"):3!`BFDP0(MI,$
M",:3!`C6DP0(YI,$"/:3!`@&E`0(%I0$"":4!`@VE`0(1I0$"%:4!`AFE`0(
M=I0$"(:4!`B6E`0(II0$"+:4!`C&E`0(UI0$".:4!`CVE`0(!I4$"!:5!`@F
ME00(-I4$"$:5!`A6E00(9I4$"':5!`B&E00(EI4$"*:5!`BVE00(QI4$"-:5
M!`CFE00(]I4$"`:6!`@6E@0()I8$"#:6!`A&E@0(5I8$"&:6!`AVE@0(AI8$
M"):6!`BFE@0(MI8$",:6!`C6E@0(``````````#_____`.,$"$=#0SH@*%5B
M=6YT=2`T+CDN,BTR,'5B=6YT=3$I(#0N.2XR`$=#0SH@*%5B=6YT=2`T+CDN
M,BTQ,'5B=6YT=3$Q*2`T+CDN,@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?
M:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD
M>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````
M``````````````````````````````````````````````````L````!````
M`@```%2!!`A4`0``$P```````````````0`````````3````!P````(```!H
M@00(:`$``"````````````````0`````````(0````<````"````B($$"(@!
M```D```````````````$`````````#0```#V__]O`@```*R!!`BL`0``7`$`
M``4`````````!`````0````^````"P````(````(@P0("`,``*`&```&````
M`0````0````0````1@````,````"````J(D$"*@)```=!0`````````````!
M`````````$X```#___]O`@```,:.!`C&#@``U`````4``````````@````(`
M``!;````_O__;P(```"<CP0(G`\``)`````&`````@````0`````````:@``
M``D````"````+)`$""P0```P````!0`````````$````"````',````)````
M0@```%R0!`A<$```&`(```4````,````!`````@```!\`````0````8```!T
MD@0(=!(``",```````````````0`````````=P````$````&````H)($"*`2
M``!`!``````````````0````!````((````!````!@```."6!`C@%@``TD@`
M````````````$`````````"(`````0````8```"TWP0(M%\``!0`````````
M``````0`````````C@````$````"````R-\$",A?``!(/P`````````````(
M`````````)8````!`````@```!`?!0@0GP``[```````````````!```````
M``"D`````0````(```#\'P4(_)\``-0-``````````````0`````````K@``
M``X````#````^#X%"/BN```$```````````````$`````````+H````/````
M`P```/P^!0C\K@``!```````````````!`````````#&`````0````,`````
M/P4(`*\```0```````````````0`````````RP````8````#````!#\%"`2O
M``#X````!@`````````$````"````-0````!`````P```/P_!0C\KP``!```
M````````````!`````0```#9`````0````,`````0`4(`+```!@!````````
M``````0````$````X@````$````#````&$$%"!BQ```0```````````````$
M`````````.@````(`````P```$!!!0@HL0``5!``````````````0```````
M``#M`````0```#``````````*+$``$D```````````````$````!`````0``
E``,``````````````'&Q``#V```````````````!````````````
